invoke method
Invokes this with the unwrapped pointer from handle and arg1.
Implementation
R invoke(NativeHandle<bssl.EVP_PKEY> handle, A1 arg1) =>
handle.use((ptr) => this(ptr, arg1));
Invokes this with the unwrapped pointer from handle and arg1.
R invoke(NativeHandle<bssl.EVP_PKEY> handle, A1 arg1) =>
handle.use((ptr) => this(ptr, arg1));