OpenSslAllocator class final

Implementation of ffi.Allocator using OPENSSL_malloc and OPENSSL_free.

Implemented types
Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
nativeFree → Pointer<NativeFinalizerFunction>
Pointer to OPENSSL_free suitable for ffi.NativeFinalizer or Pointer<Uint8>.asTypedList(len, finalizer: opensslAllocator.nativeFree).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate<T extends NativeType>(int byteCount, {int? alignment}) → Pointer<T>
Allocates byteCount bytes of memory on the native heap.
override
call<T extends SizedNativeType>([int count = 1]) → Pointer<T>

Available on Allocator, provided by the AllocatorAlloc extension

Allocates sizeOf<T>() * count bytes of memory using allocate.
copyBytes<T extends NativeType>(List<int> data) → Pointer<T>

Available on Allocator, provided by the AllocatorCopyBytes extension

Allocates data.length bytes and copies data into them.
free(Pointer<NativeType> pointer) → void
Releases memory allocated on the native heap.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited