free method
Releases memory allocated on the native heap.
Throws an ArgumentError if the memory pointed to by pointer cannot be
freed.
Implementation
@override
void free(ffi.Pointer<ffi.NativeType> pointer) {
bssl.OPENSSL_free(pointer.cast());
}
Releases memory allocated on the native heap.
Throws an ArgumentError if the memory pointed to by pointer cannot be
freed.
@override
void free(ffi.Pointer<ffi.NativeType> pointer) {
bssl.OPENSSL_free(pointer.cast());
}