AES_cfb128_encrypt function
- @RecordUse.new()
- @Native<Void Function(Pointer<
Uint8> , Pointer<Uint8> , Size, Pointer<AES_KEY> , Pointer<Uint8> , Pointer<Int> , Int)>(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>, ffi.Size, ffi.Pointer<AES_KEY>, ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Int>, ffi.Int)>(symbol: 'bssl_dart_AES_cfb128_encrypt')
AES_cfb128_encrypt encrypts (or decrypts, if |enc| == |AES_DECRYPT|) |len| bytes from |in| to |out|. The |num| parameter must be set to zero on the first call. This function may be called in-place with |in| equal to |out|, but otherwise the buffers may not partially overlap. A partial overlap may overwrite input data before it is read.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Void Function(
ffi.Pointer<ffi.Uint8>,
ffi.Pointer<ffi.Uint8>,
ffi.Size,
ffi.Pointer<AES_KEY>,
ffi.Pointer<ffi.Uint8>,
ffi.Pointer<ffi.Int>,
ffi.Int,
)
>(symbol: 'bssl_dart_AES_cfb128_encrypt')
external void AES_cfb128_encrypt(
ffi.Pointer<ffi.Uint8> in$,
ffi.Pointer<ffi.Uint8> out,
int len,
ffi.Pointer<AES_KEY> key,
ffi.Pointer<ffi.Uint8> ivec,
ffi.Pointer<ffi.Int> num,
int enc,
);