AES_ofb128_encrypt function

  1. @RecordUse.new()
  2. @Native<Void Function(Pointer<Uint8>, Pointer<Uint8>, Size, Pointer<AES_KEY>, Pointer<Uint8>, Pointer<Int>)>(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>, ffi.Size, ffi.Pointer<AES_KEY>, ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Int>)>(symbol: 'bssl_dart_AES_ofb128_encrypt')
void AES_ofb128_encrypt(
  1. Pointer<Uint8> in$,
  2. Pointer<Uint8> out,
  3. int len,
  4. Pointer<AES_KEY> key,
  5. Pointer<Uint8> ivec,
  6. Pointer<Int> num,
)

AES_ofb128_encrypt encrypts (or decrypts, it's the same in OFB mode) |len| bytes from |in| to |out|. The |num| parameter must be set to zero on the first call. This function may be called in-place with |in| equal to |out|, but otherwise the buffers may not partially overlap. A partial overlap may overwrite input data before it is read.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Void Function(
    ffi.Pointer<ffi.Uint8>,
    ffi.Pointer<ffi.Uint8>,
    ffi.Size,
    ffi.Pointer<AES_KEY>,
    ffi.Pointer<ffi.Uint8>,
    ffi.Pointer<ffi.Int>,
  )
>(symbol: 'bssl_dart_AES_ofb128_encrypt')
external void AES_ofb128_encrypt(
  ffi.Pointer<ffi.Uint8> in$,
  ffi.Pointer<ffi.Uint8> out,
  int len,
  ffi.Pointer<AES_KEY> key,
  ffi.Pointer<ffi.Uint8> ivec,
  ffi.Pointer<ffi.Int> num,
);