ASN1_STRING_TABLE_add function
- @RecordUse.new()
- @Native<Int Function(Int, Long, Long, UnsignedLong, UnsignedLong)>(ffi.Int, ffi.Long, ffi.Long, ffi.UnsignedLong, ffi.UnsignedLong)>(symbol: 'bssl_dart_ASN1_STRING_TABLE_add')
ASN1_STRING_TABLE_add registers the corresponding parameters with |nid|, for use with |ASN1_STRING_set_by_NID|. It returns one on success and zero on error. It is an error to call this function if |nid| is a built-in NID, or was already registered by a previous call.
WARNING: This function affects global state in the library. If two libraries in the same address space register information for the same OID, one call will fail. Prefer directly passing the desired parameters to |ASN1_mbstring_copy| or |ASN1_mbstring_ncopy| instead.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Int,
ffi.Long,
ffi.Long,
ffi.UnsignedLong,
ffi.UnsignedLong,
)
>(symbol: 'bssl_dart_ASN1_STRING_TABLE_add')
external int ASN1_STRING_TABLE_add(
int nid,
int minsize,
int maxsize,
int mask,
int flags,
);