ASN1_STRING_set0 function

  1. @RecordUse.new()
  2. @Native<Void Function(Pointer<ASN1_OCTET_STRING>, Pointer<Void>, Int)>(ffi.Pointer<ASN1_STRING>, ffi.Pointer<ffi.Void>, ffi.Int)>(symbol: 'bssl_dart_ASN1_STRING_set0')
void ASN1_STRING_set0(
  1. Pointer<ASN1_OCTET_STRING> str,
  2. Pointer<Void> data,
  3. int len
)

ASN1_STRING_set0 sets the contents of |str| to |len| bytes from |data|. It takes ownership of |data|, which must have been allocated with |OPENSSL_malloc|.

If |str| is a BIT STRING, this function sets the number of unused bits to zero. |ASN1_BIT_STRING_set1| may be used to set a BIT STRING that is not a whole number of bytes.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Void Function(ffi.Pointer<ASN1_STRING>, ffi.Pointer<ffi.Void>, ffi.Int)
>(symbol: 'bssl_dart_ASN1_STRING_set0')
external void ASN1_STRING_set0(
  ffi.Pointer<ASN1_STRING> str,
  ffi.Pointer<ffi.Void> data,
  int len,
);