ASN1_item_free function

  1. @RecordUse.new()
  2. @Native<Void Function(Pointer<ASN1_VALUE>, Pointer<ASN1_ITEM>)>(ffi.Pointer<ASN1_VALUE>, ffi.Pointer<ASN1_ITEM>)>(symbol: 'bssl_dart_ASN1_item_free')
void ASN1_item_free(
  1. Pointer<ASN1_VALUE> val,
  2. Pointer<ASN1_ITEM> it
)

ASN1_item_free releases memory associated with |val|, which must be an object of the C type corresponding to |it|.

This function may not be used with |ASN1_ITEM|s whose C type is |ASN1_BOOLEAN|.

WARNING: Passing a pointer of the wrong type into this function is a potentially exploitable memory error. Callers must ensure |val| is consistent with |it|. Prefer using type-specific functions such as |ASN1_OCTET_STRING_free|.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Void Function(ffi.Pointer<ASN1_VALUE>, ffi.Pointer<ASN1_ITEM>)>(
  symbol: 'bssl_dart_ASN1_item_free',
)
external void ASN1_item_free(
  ffi.Pointer<ASN1_VALUE> val,
  ffi.Pointer<ASN1_ITEM> it,
);