ASN1_item_new function

  1. @RecordUse.new()
  2. @Native<Pointer<ASN1_VALUE> Function(Pointer<ASN1_ITEM> it)>(ffi.Pointer<ASN1_ITEM>)>(symbol: 'bssl_dart_ASN1_item_new')
Pointer<ASN1_VALUE> ASN1_item_new(
  1. Pointer<ASN1_ITEM> it
)

ASN1_item_new allocates a new value of the C type corresponding to |it|, or NULL on error. On success, the caller must release the value with |ASN1_item_free|, or the corresponding C type's free function, when done. The new value will initialize fields of the value to some default state, such as an empty string. Note, however, that this default state sometimes omits required values, such as with CHOICE types.

This function may not be used with |ASN1_ITEM|s whose C type is |ASN1_BOOLEAN|.

WARNING: Casting the result of this function to the wrong type is a potentially exploitable memory error. Callers must ensure the value is used consistently with |it|. Prefer using type-specific functions such as |ASN1_OCTET_STRING_new|.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Pointer<ASN1_VALUE> Function(ffi.Pointer<ASN1_ITEM>)>(
  symbol: 'bssl_dart_ASN1_item_new',
)
external ffi.Pointer<ASN1_VALUE> ASN1_item_new(
  ffi.Pointer<ASN1_ITEM> it,
);