BASIC_CONSTRAINTS_st class final

A BASIC_CONSTRAINTS_st, aka |BASIC_CONSTRAINTS| represents an BasicConstraints structure (RFC 5280).

Inheritance
Implemented types
Available extensions

Constructors

BASIC_CONSTRAINTS_st()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
ca ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pathlen ↔ Pointer<ASN1_OCTET_STRING>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required int ca, required Pointer<ASN1_OCTET_STRING> pathlen}) → Pointer<BASIC_CONSTRAINTS>