BIO_new_mem_buf function

  1. @RecordUse.new()
  2. @Native<Pointer<BIO> Function(Pointer<Void>, ossl_ssize_t)>(ffi.Pointer<ffi.Void>, ossl_ssize_t)>(symbol: 'bssl_dart_BIO_new_mem_buf')
Pointer<BIO> BIO_new_mem_buf(
  1. Pointer<Void> buf,
  2. int len
)

BIO_new_mem_buf creates read-only BIO that reads from |len| bytes at |buf|. It returns the BIO or NULL on error. This function does not copy or take ownership of |buf|. The caller must ensure the memory pointed to by |buf| outlives the |BIO|.

If |len| is negative, then |buf| is treated as a NUL-terminated string, but don't depend on this in new code.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Pointer<BIO> Function(ffi.Pointer<ffi.Void>, ossl_ssize_t)>(
  symbol: 'bssl_dart_BIO_new_mem_buf',
)
external ffi.Pointer<BIO> BIO_new_mem_buf(
  ffi.Pointer<ffi.Void> buf,
  int len,
);