CBB_add_asn1_oid_from_text function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<CBB>, Pointer<Char>, Size)>(ffi.Pointer<CBB>, ffi.Pointer<ffi.Char>, ffi.Size)>(symbol: 'bssl_dart_CBB_add_asn1_oid_from_text')
int CBB_add_asn1_oid_from_text(
  1. Pointer<CBB> cbb,
  2. Pointer<Char> text,
  3. int len
)

CBB_add_asn1_oid_from_text decodes |len| bytes from |text| as an ASCII OID representation, e.g. "1.2.840.113554.4.1.72585", and writes the DER-encoded contents to |cbb|. It returns one on success and zero on malloc failure or if |text| was invalid. It does not include the OBJECT IDENTIFIER framing, only the element's contents.

This function considers OID strings with components which do not fit in a |uint64_t| to be invalid.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(ffi.Pointer<CBB>, ffi.Pointer<ffi.Char>, ffi.Size)
>(symbol: 'bssl_dart_CBB_add_asn1_oid_from_text')
external int CBB_add_asn1_oid_from_text(
  ffi.Pointer<CBB> cbb,
  ffi.Pointer<ffi.Char> text,
  int len,
);