CBB_data function

  1. @RecordUse.new()
  2. @Native<Pointer<Uint8> Function(Pointer<CBB> cbb)>(ffi.Pointer<CBB>)>(symbol: 'bssl_dart_CBB_data')
Pointer<Uint8> CBB_data(
  1. Pointer<CBB> cbb
)

CBB_data returns a pointer to the bytes written to |cbb|. It does not flush |cbb|. The pointer is valid until the next operation to |cbb|.

To avoid unfinalized length prefixes, it is a fatal error to call this on a CBB with any active children.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Pointer<ffi.Uint8> Function(ffi.Pointer<CBB>)>(
  symbol: 'bssl_dart_CBB_data',
)
external ffi.Pointer<ffi.Uint8> CBB_data(
  ffi.Pointer<CBB> cbb,
);