CRYPTO_dynlock class final

Inheritance
Implemented types
Available extensions

Constructors

CRYPTO_dynlock()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
data ↔ Pointer<CRYPTO_dynlock_value>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
references ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required int references, required Pointer<CRYPTO_dynlock_value> data}) → Pointer<CRYPTO_dynlock>