DH_size function
DH_size returns the number of bytes in the DH group's prime.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<DH>)>(symbol: 'bssl_dart_DH_size')
external int DH_size(
ffi.Pointer<DH> dh,
);
DH_size returns the number of bytes in the DH group's prime.
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<DH>)>(symbol: 'bssl_dart_DH_size')
external int DH_size(
ffi.Pointer<DH> dh,
);