DSA_marshal_public_key function
DSA_marshal_public_key marshals |dsa| as a DER-encoded DSA public key and appends the result to |cbb|. It returns one on success and zero on failure.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<CBB>, ffi.Pointer<DSA>)>(
symbol: 'bssl_dart_DSA_marshal_public_key',
)
external int DSA_marshal_public_key(
ffi.Pointer<CBB> cbb,
ffi.Pointer<DSA> dsa,
);