EC_KEY_check_fips function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<EC_KEY> key)>(ffi.Pointer<EC_KEY>)>(symbol: 'bssl_dart_EC_KEY_check_fips')
int EC_KEY_check_fips(
  1. Pointer<EC_KEY> key
)

EC_KEY_check_fips performs both a signing pairwise consistency test (FIPS 140-2 4.9.2) and the consistency test from SP 800-56Ar3 section 5.6.2.1.4. It returns one if it passes and zero otherwise.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<EC_KEY>)>(
  symbol: 'bssl_dart_EC_KEY_check_fips',
)
external int EC_KEY_check_fips(
  ffi.Pointer<EC_KEY> key,
);