EC_KEY_generate_key_fips function
EC_KEY_generate_key_fips behaves like |EC_KEY_generate_key| but performs additional checks for FIPS compliance. This function is applicable when generating keys for either signing/verification or key agreement because both types of consistency check (PCT) are performed.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<EC_KEY>)>(
symbol: 'bssl_dart_EC_KEY_generate_key_fips',
)
external int EC_KEY_generate_key_fips(
ffi.Pointer<EC_KEY> key,
);