ED25519_keypair_from_seed function

  1. @RecordUse.new()
  2. @Native<Void Function(Pointer<Uint8>, Pointer<Uint8>, Pointer<Uint8>)>(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>)>(symbol: 'bssl_dart_ED25519_keypair_from_seed')
void ED25519_keypair_from_seed(
  1. Pointer<Uint8> out_public_key,
  2. Pointer<Uint8> out_private_key,
  3. Pointer<Uint8> seed
)

ED25519_keypair_from_seed calculates a public and private key from an Ed25519 “seed”. Seed values are not exposed by this API (although they happen to be the first 32 bytes of a private key) so this function is for interoperating with systems that may store just a seed instead of a full private key.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Void Function(
    ffi.Pointer<ffi.Uint8>,
    ffi.Pointer<ffi.Uint8>,
    ffi.Pointer<ffi.Uint8>,
  )
>(symbol: 'bssl_dart_ED25519_keypair_from_seed')
external void ED25519_keypair_from_seed(
  ffi.Pointer<ffi.Uint8> out_public_key,
  ffi.Pointer<ffi.Uint8> out_private_key,
  ffi.Pointer<ffi.Uint8> seed,
);