EDIPartyName_st class final

Inheritance
Implemented types
Available extensions

Constructors

EDIPartyName_st()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
nameAssigner ↔ Pointer<ASN1_OCTET_STRING>
getter/setter pair
partyName ↔ Pointer<ASN1_OCTET_STRING>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required Pointer<ASN1_OCTET_STRING> nameAssigner, required Pointer<ASN1_OCTET_STRING> partyName}) → Pointer<EDIPARTYNAME>