ERR_get_next_error_library function

  1. @RecordUse.new()
  2. @Native<Int Function()>()>(symbol: 'bssl_dart_ERR_get_next_error_library')
int ERR_get_next_error_library()

ERR_get_next_error_library returns a value suitable for passing as the |library| argument to |ERR_put_error|. This is intended for code that wishes to push its own, non-standard errors to the error queue.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function()>(symbol: 'bssl_dart_ERR_get_next_error_library')
external int ERR_get_next_error_library();