ERR_lib_error_string function

  1. @RecordUse.new()
  2. @Native<Pointer<Char> Function(Uint32)>(ffi.Uint32)>(symbol: 'bssl_dart_ERR_lib_error_string')
Pointer<Char> ERR_lib_error_string(
  1. int packed_error
)

ERR_lib_error_string returns a string representation of the library that generated |packed_error|, or a placeholder string is the library is unrecognized.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Pointer<ffi.Char> Function(ffi.Uint32)>(
  symbol: 'bssl_dart_ERR_lib_error_string',
)
external ffi.Pointer<ffi.Char> ERR_lib_error_string(
  int packed_error,
);