EVP_DecodeBase64 function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<Uint8>, Pointer<Size>, Size, Pointer<Uint8>, Size)>(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Size>, ffi.Size, ffi.Pointer<ffi.Uint8>, ffi.Size)>(symbol: 'bssl_dart_EVP_DecodeBase64')
int EVP_DecodeBase64(
  1. Pointer<Uint8> out,
  2. Pointer<Size> out_len,
  3. int max_out,
  4. Pointer<Uint8> in$,
  5. int in_len,
)

EVP_DecodeBase64 decodes |in_len| bytes from base64 and writes |*out_len| bytes to |out|. |max_out| is the size of the output buffer. If it is not enough for the maximum output size, the operation fails. It returns one on success or zero on error.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(
    ffi.Pointer<ffi.Uint8>,
    ffi.Pointer<ffi.Size>,
    ffi.Size,
    ffi.Pointer<ffi.Uint8>,
    ffi.Size,
  )
>(symbol: 'bssl_dart_EVP_DecodeBase64')
external int EVP_DecodeBase64(
  ffi.Pointer<ffi.Uint8> out,
  ffi.Pointer<ffi.Size> out_len,
  int max_out,
  ffi.Pointer<ffi.Uint8> in$,
  int in_len,
);