EVP_DecodeBlock function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<Uint8>, Pointer<Uint8>, Size)>(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>, ffi.Size)>(symbol: 'bssl_dart_EVP_DecodeBlock')
int EVP_DecodeBlock(
  1. Pointer<Uint8> dst,
  2. Pointer<Uint8> src,
  3. int src_len
)

EVP_DecodeBlock encodes |src_len| bytes from |src| and writes the result to |dst|. It returns the number of bytes written or -1 on error.

WARNING: EVP_DecodeBlock's return value does not take padding into account. It also strips leading whitespace and trailing whitespace and minuses.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>, ffi.Size)
>(symbol: 'bssl_dart_EVP_DecodeBlock')
external int EVP_DecodeBlock(
  ffi.Pointer<ffi.Uint8> dst,
  ffi.Pointer<ffi.Uint8> src,
  int src_len,
);