EVP_DigestInit_ex function
EVP_DigestInit_ex configures |ctx|, which must already have been initialised, for a fresh hashing operation using |type|. It returns one on success and zero on allocation failure.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<EVP_MD_CTX>,
ffi.Pointer<EVP_MD>,
ffi.Pointer<ENGINE>,
)
>(symbol: 'bssl_dart_EVP_DigestInit_ex')
external int EVP_DigestInit_ex(
ffi.Pointer<EVP_MD_CTX> ctx,
ffi.Pointer<EVP_MD> type,
ffi.Pointer<ENGINE> engine,
);