EVP_DigestSign function
EVP_DigestSign signs |data_len| bytes from |data| using |ctx|. If |out_sig| is NULL then |*out_sig_len| is set to the maximum number of output bytes. Otherwise, on entry, |*out_sig_len| must contain the length of the |out_sig| buffer. If the call is successful, the signature is written to |out_sig| and |*out_sig_len| is set to its length.
It returns one on success and zero on error.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<EVP_MD_CTX>,
ffi.Pointer<ffi.Uint8>,
ffi.Pointer<ffi.Size>,
ffi.Pointer<ffi.Uint8>,
ffi.Size,
)
>(symbol: 'bssl_dart_EVP_DigestSign')
external int EVP_DigestSign(
ffi.Pointer<EVP_MD_CTX> ctx,
ffi.Pointer<ffi.Uint8> out_sig,
ffi.Pointer<ffi.Size> out_sig_len,
ffi.Pointer<ffi.Uint8> data,
int data_len,
);