EVP_DigestVerifyFinal function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<EVP_MD_CTX>, Pointer<Uint8>, Size)>(ffi.Pointer<EVP_MD_CTX>, ffi.Pointer<ffi.Uint8>, ffi.Size)>(symbol: 'bssl_dart_EVP_DigestVerifyFinal')
int EVP_DigestVerifyFinal(
  1. Pointer<EVP_MD_CTX> ctx,
  2. Pointer<Uint8> sig,
  3. int sig_len
)

EVP_DigestVerifyFinal verifies that |sig_len| bytes of |sig| are a valid signature for the data that has been included by one or more calls to |EVP_DigestVerifyUpdate|. It returns one on success and zero otherwise.

This function performs streaming signature verification and will fail for signature algorithms which do not support this. Use |EVP_DigestVerify| for a single-shot verification.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(ffi.Pointer<EVP_MD_CTX>, ffi.Pointer<ffi.Uint8>, ffi.Size)
>(symbol: 'bssl_dart_EVP_DigestVerifyFinal')
external int EVP_DigestVerifyFinal(
  ffi.Pointer<EVP_MD_CTX> ctx,
  ffi.Pointer<ffi.Uint8> sig,
  int sig_len,
);