EVP_EncryptFinal_ex function
EVP_EncryptFinal_ex does the same as |EVP_EncryptFinal_ex2|, except that no output size is given and thus no bounds checking is performed.
WARNING: This function does not check bounds on out, and correctly sizing the output buffer is difficult. Use |EVP_EncryptFinal_ex2| instead.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<EVP_CIPHER_CTX>,
ffi.Pointer<ffi.Uint8>,
ffi.Pointer<ffi.Int>,
)
>(symbol: 'bssl_dart_EVP_EncryptFinal_ex')
external int EVP_EncryptFinal_ex(
ffi.Pointer<EVP_CIPHER_CTX> ctx,
ffi.Pointer<ffi.Uint8> out,
ffi.Pointer<ffi.Int> out_len,
);