EVP_MD_CTX_copy_ex function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<EVP_MD_CTX>, Pointer<EVP_MD_CTX>)>(ffi.Pointer<EVP_MD_CTX>, ffi.Pointer<EVP_MD_CTX>)>(symbol: 'bssl_dart_EVP_MD_CTX_copy_ex')
int EVP_MD_CTX_copy_ex(
  1. Pointer<EVP_MD_CTX> out,
  2. Pointer<EVP_MD_CTX> in$
)

EVP_MD_CTX_copy_ex sets |out|, which must already be initialised, to be a copy of |in|. It returns one on success and zero on allocation failure.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<EVP_MD_CTX>, ffi.Pointer<EVP_MD_CTX>)>(
  symbol: 'bssl_dart_EVP_MD_CTX_copy_ex',
)
external int EVP_MD_CTX_copy_ex(
  ffi.Pointer<EVP_MD_CTX> out,
  ffi.Pointer<EVP_MD_CTX> in$,
);