EVP_PKEY_is_opaque function
EVP_PKEY_is_opaque returns one if |pkey| is opaque. Opaque keys are backed by custom implementations which do not expose key material and parameters. It is an error to attempt to duplicate, export, or compare an opaque key.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<EVP_PKEY>)>(
symbol: 'bssl_dart_EVP_PKEY_is_opaque',
)
external int EVP_PKEY_is_opaque(
ffi.Pointer<EVP_PKEY> pkey,
);