EVP_PKEY_set1_tls_encodedpoint function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<EVP_PKEY>, Pointer<Uint8>, Size)>(ffi.Pointer<EVP_PKEY>, ffi.Pointer<ffi.Uint8>, ffi.Size)>(symbol: 'bssl_dart_EVP_PKEY_set1_tls_encodedpoint')
int EVP_PKEY_set1_tls_encodedpoint(
  1. Pointer<EVP_PKEY> pkey,
  2. Pointer<Uint8> in$,
  3. int len
)

EVP_PKEY_set1_tls_encodedpoint replaces |pkey| with a public key encoded by |in|. It returns one on success and zero on error.

If |pkey| is an EC key, the format is an X9.62 point and |pkey| must already have an EC group configured. If it is an X25519 key, it is the 32-byte X25519 public key representation. This function is not supported for other key types and will fail.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(ffi.Pointer<EVP_PKEY>, ffi.Pointer<ffi.Uint8>, ffi.Size)
>(symbol: 'bssl_dart_EVP_PKEY_set1_tls_encodedpoint')
external int EVP_PKEY_set1_tls_encodedpoint(
  ffi.Pointer<EVP_PKEY> pkey,
  ffi.Pointer<ffi.Uint8> in$,
  int len,
);