EVP_aead_aes_256_gcm function
EVP_aead_aes_256_gcm is AES-256 in Galois Counter Mode.
Note: AES-GCM should only be used with 12-byte (96-bit) nonces. Although it is specified to take a variable-length nonce, nonces with other lengths are effectively randomized, which means one must consider collisions. Unless implementing an existing protocol which has already specified incorrect parameters, only use 12-byte nonces.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<EVP_AEAD> Function()>(
symbol: 'bssl_dart_EVP_aead_aes_256_gcm',
)
external ffi.Pointer<EVP_AEAD> EVP_aead_aes_256_gcm();