EVP_pkey_dsa function
- @RecordUse.new()
- @Native<Pointer<
EVP_PKEY_ALG> Function()>()>(symbol: 'bssl_dart_EVP_pkey_dsa')
EVP_pkey_dsa implements DSA keys, encoded as in RFC 3279, Section 2.3.2. The |EVP_PKEY_id| value is |EVP_PKEY_DSA|. This |EVP_PKEY_ALG| accepts all DSA parameters supported by BoringSSL.
Keys of this type are not usable with any operations, though the underlying |DSA| object can be extracted with |EVP_PKEY_get0_DSA|. This key type is deprecated and only implemented for compatibility with legacy applications.
TODO(crbug.com/42290364): We didn't wire up |EVP_PKEY_sign| and |EVP_PKEY_verify| just so it was auditable which callers used DSA. Once DSA is removed from the default SPKI and PKCS#8 parser and DSA users explicitly request |EVP_pkey_dsa|, we could change that.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<EVP_PKEY_ALG> Function()>(
symbol: 'bssl_dart_EVP_pkey_dsa',
)
external ffi.Pointer<EVP_PKEY_ALG> EVP_pkey_dsa();