OBJ_cmp function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<ASN1_OBJECT>, Pointer<ASN1_OBJECT>)>(ffi.Pointer<ASN1_OBJECT>, ffi.Pointer<ASN1_OBJECT>)>(symbol: 'bssl_dart_OBJ_cmp')
int OBJ_cmp(
  1. Pointer<ASN1_OBJECT> a,
  2. Pointer<ASN1_OBJECT> b
)

OBJ_cmp returns a value less than, equal to or greater than zero if |a| is less than, equal to or greater than |b|, respectively.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(ffi.Pointer<ASN1_OBJECT>, ffi.Pointer<ASN1_OBJECT>)
>(symbol: 'bssl_dart_OBJ_cmp')
external int OBJ_cmp(
  ffi.Pointer<ASN1_OBJECT> a,
  ffi.Pointer<ASN1_OBJECT> b,
);