PKCS7_get_PEM_CRLs function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<stack_st_X509_CRL>, Pointer<BIO>)>(ffi.Pointer<stack_st_X509_CRL>, ffi.Pointer<BIO>)>(symbol: 'bssl_dart_PKCS7_get_PEM_CRLs')
int PKCS7_get_PEM_CRLs(
  1. Pointer<stack_st_X509_CRL> out_crls,
  2. Pointer<BIO> pem_bio
)

PKCS7_get_PEM_CRLs reads a PEM-encoded, PKCS#7, SignedData structure from |pem_bio| and appends the included CRLs to |out_crls|. It returns one on success and zero on error.

Note that a SignedData structure may contain no CRLs, in which case this function succeeds but does not append any CRLs. Additionally, CRLs in SignedData structures are unordered. Callers should not assume an order in |*out_crls| and may need to search for matches.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<stack_st_X509_CRL>, ffi.Pointer<BIO>)>(
  symbol: 'bssl_dart_PKCS7_get_PEM_CRLs',
)
external int PKCS7_get_PEM_CRLs(
  ffi.Pointer<stack_st_X509_CRL> out_crls,
  ffi.Pointer<BIO> pem_bio,
);