POLICYINFO_st class final

A POLICYINFO represents a PolicyInformation structure (RFC 5280).

Inheritance
Implemented types
Available extensions

Constructors

POLICYINFO_st()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
policyid ↔ Pointer<ASN1_OBJECT>
getter/setter pair
qualifiers ↔ Pointer<stack_st_POLICYQUALINFO>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required Pointer<ASN1_OBJECT> policyid, required Pointer<stack_st_POLICYQUALINFO> qualifiers}) → Pointer<POLICYINFO>