RAND_get_system_entropy_for_custom_prng function
RAND_get_system_entropy_for_custom_prng writes |len| bytes of random data from a system entropy source to |buf|. The maximum length of entropy which may be requested is 256 bytes. If more than 256 bytes of data is requested, or if sufficient random data can not be obtained, |abort| is called. |RAND_bytes| should normally be used instead of this function. This function should only be used for seed values or where |malloc| should not be called from BoringSSL. This function is not FIPS compliant.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Void Function(ffi.Pointer<ffi.Uint8>, ffi.Size)>(
symbol: 'bssl_dart_RAND_get_system_entropy_for_custom_prng',
)
external void RAND_get_system_entropy_for_custom_prng(
ffi.Pointer<ffi.Uint8> buf,
int len,
);