RSA_check_key function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<RSA> rsa)>(ffi.Pointer<RSA>)>(symbol: 'bssl_dart_RSA_check_key')
int RSA_check_key(
  1. Pointer<RSA> rsa
)

RSA_check_key performs basic validity tests on |rsa|. It returns one if they pass and zero otherwise. Opaque keys and public keys always pass. If it returns zero then a more detailed error is available on the error queue.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<RSA>)>(
  symbol: 'bssl_dart_RSA_check_key',
)
external int RSA_check_key(
  ffi.Pointer<RSA> rsa,
);