RSA_get0_pss_params function
- @RecordUse.new()
- @Native<Pointer<
RSA_PSS_PARAMS> Function(Pointer<RSA> rsa)>(ffi.Pointer<RSA>)>(symbol: 'bssl_dart_RSA_get0_pss_params')
RSA_get0_pss_params returns NULL. In OpenSSL, this function retries RSA-PSS parameters associated with |RSA| objects, but BoringSSL does not enable the id-RSASSA-PSS key encoding by default.
WARNING: BoringSSL does support id-RSASSA-PSS parameters when callers opt in (see |EVP_pkey_rsa_pss_sha256| and others). We currently assume such callers do not need this function. Callers that opt into id-RSASSA-PSS support and require this functionality should contact the BoringSSL team.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<RSA_PSS_PARAMS> Function(ffi.Pointer<RSA>)>(
symbol: 'bssl_dart_RSA_get0_pss_params',
)
external ffi.Pointer<RSA_PSS_PARAMS> RSA_get0_pss_params(
ffi.Pointer<RSA> rsa,
);