RSA_new_private_key_no_e function

  1. @RecordUse.new()
  2. @Native<Pointer<RSA> Function(Pointer<BIGNUM> n, Pointer<BIGNUM> d)>(ffi.Pointer<BIGNUM>, ffi.Pointer<BIGNUM>)>(symbol: 'bssl_dart_RSA_new_private_key_no_e')
Pointer<RSA> RSA_new_private_key_no_e(
  1. Pointer<BIGNUM> n,
  2. Pointer<BIGNUM> d
)

RSA_new_private_key_no_e behaves like |RSA_new_private_key| but constructs an RSA key without CRT parameters or public exponent.

Keys created by this function will be less performant, cannot be serialized, and lack hardening measures that protect against side channels and fault attacks.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Pointer<RSA> Function(ffi.Pointer<BIGNUM>, ffi.Pointer<BIGNUM>)
>(symbol: 'bssl_dart_RSA_new_private_key_no_e')
external ffi.Pointer<RSA> RSA_new_private_key_no_e(
  ffi.Pointer<BIGNUM> n,
  ffi.Pointer<BIGNUM> d,
);