UnnamedUnion$3 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedUnion$3()

Properties

address → Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
base ↔ cbb_buffer_st
getter/setter pair
child ↔ cbb_child_st
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited