X509_EXTENSION_create_by_NID function

  1. @RecordUse.new()
  2. @Native<Pointer<X509_EXTENSION> Function(Pointer<Pointer<X509_EXTENSION>>, Int, Int, Pointer<ASN1_OCTET_STRING>)>(ffi.Pointer<ffi.Pointer<X509_EXTENSION>>, ffi.Int, ffi.Int, ffi.Pointer<ASN1_OCTET_STRING>)>(symbol: 'bssl_dart_X509_EXTENSION_create_by_NID')
Pointer<X509_EXTENSION> X509_EXTENSION_create_by_NID(
  1. Pointer<Pointer<X509_EXTENSION>> ex,
  2. int nid,
  3. int crit,
  4. Pointer<ASN1_OCTET_STRING> data,
)

X509_EXTENSION_create_by_NID creates a new |X509_EXTENSION| with type |nid|, value |data|, and critical bit |crit|. It returns an |X509_EXTENSION| on success, and NULL on error. |nid| should be a |NID_*| constant.

If |ex| and |*ex| are both non-NULL, |*ex| is used to hold the result, otherwise a new object is allocated. If |ex| is non-NULL and |*ex| is NULL, the function sets |*ex| to point to the newly allocated result, in addition to returning the result.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Pointer<X509_EXTENSION> Function(
    ffi.Pointer<ffi.Pointer<X509_EXTENSION>>,
    ffi.Int,
    ffi.Int,
    ffi.Pointer<ASN1_OCTET_STRING>,
  )
>(symbol: 'bssl_dart_X509_EXTENSION_create_by_NID')
external ffi.Pointer<X509_EXTENSION> X509_EXTENSION_create_by_NID(
  ffi.Pointer<ffi.Pointer<X509_EXTENSION>> ex,
  int nid,
  int crit,
  ffi.Pointer<ASN1_OCTET_STRING> data,
);