X509_NAME_oneline function

  1. @RecordUse.new()
  2. @Native<Pointer<Char> Function(Pointer<X509_NAME>, Pointer<Char>, Int)>(ffi.Pointer<X509_NAME>, ffi.Pointer<ffi.Char>, ffi.Int)>(symbol: 'bssl_dart_X509_NAME_oneline')
Pointer<Char> X509_NAME_oneline(
  1. Pointer<X509_NAME> name,
  2. Pointer<Char> buf,
  3. int size
)

X509_NAME_oneline writes a human-readable representation to |name| to a buffer as a NUL-terminated C string.

If |buf| is NULL, returns a newly-allocated buffer containing the result on success, or NULL on error. The buffer must be released with |OPENSSL_free| when done.

If |buf| is non-NULL, at most |size| bytes of output are written to |buf| instead. |size| includes the trailing NUL. The function then returns |buf| on success or NULL on error. If the output does not fit in |size| bytes, the output is silently truncated at an attribute boundary.

This function outputs a legacy format that does not correctly handle string encodings and other cases. Prefer |X509_NAME_print_ex| if printing a name for debugging purposes.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Pointer<ffi.Char> Function(
    ffi.Pointer<X509_NAME>,
    ffi.Pointer<ffi.Char>,
    ffi.Int,
  )
>(symbol: 'bssl_dart_X509_NAME_oneline')
external ffi.Pointer<ffi.Char> X509_NAME_oneline(
  ffi.Pointer<X509_NAME> name,
  ffi.Pointer<ffi.Char> buf,
  int size,
);