X509_REVOKED_add_ext function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<X509_REVOKED>, Pointer<X509_EXTENSION>, Int)>(ffi.Pointer<X509_REVOKED>, ffi.Pointer<X509_EXTENSION>, ffi.Int)>(symbol: 'bssl_dart_X509_REVOKED_add_ext')
int X509_REVOKED_add_ext(
  1. Pointer<X509_REVOKED> x,
  2. Pointer<X509_EXTENSION> ex,
  3. int loc
)

X509_REVOKED_add_ext adds a copy of |ex| to |x|. It returns one on success and zero on failure. The caller retains ownership of |ex| and can release it independently of |x|.

The new extension is inserted at index |loc|, shifting extensions to the right. If |loc| is -1 or out of bounds, the new extension is appended to the list.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(
    ffi.Pointer<X509_REVOKED>,
    ffi.Pointer<X509_EXTENSION>,
    ffi.Int,
  )
>(symbol: 'bssl_dart_X509_REVOKED_add_ext')
external int X509_REVOKED_add_ext(
  ffi.Pointer<X509_REVOKED> x,
  ffi.Pointer<X509_EXTENSION> ex,
  int loc,
);