X509_STORE_CTX_get0_chain function

  1. @RecordUse.new()
  2. @Native<Pointer<stack_st_X509> Function(Pointer<X509_STORE_CTX> ctx)>(ffi.Pointer<X509_STORE_CTX>)>(symbol: 'bssl_dart_X509_STORE_CTX_get0_chain')
Pointer<stack_st_X509> X509_STORE_CTX_get0_chain(
  1. Pointer<X509_STORE_CTX> ctx
)

X509_STORE_CTX_get0_chain, after a successful |X509_verify_cert| call, returns the verified certificate chain. The chain begins with the leaf and ends with trust anchor.

At other points, such as after a failed verification or during the deprecated verification callback, it returns the partial chain built so far. Callers should avoid relying on this as this exposes unstable library implementation details.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Pointer<stack_st_X509> Function(ffi.Pointer<X509_STORE_CTX>)>(
  symbol: 'bssl_dart_X509_STORE_CTX_get0_chain',
)
external ffi.Pointer<stack_st_X509> X509_STORE_CTX_get0_chain(
  ffi.Pointer<X509_STORE_CTX> ctx,
);