X509_STORE_add_lookup function

  1. @RecordUse.new()
  2. @Native<Pointer<X509_LOOKUP> Function(Pointer<X509_STORE> store, Pointer<X509_LOOKUP_METHOD> method)>(ffi.Pointer<X509_STORE>, ffi.Pointer<X509_LOOKUP_METHOD>)>(symbol: 'bssl_dart_X509_STORE_add_lookup')
Pointer<X509_LOOKUP> X509_STORE_add_lookup(
  1. Pointer<X509_STORE> store,
  2. Pointer<X509_LOOKUP_METHOD> method
)

X509_STORE_add_lookup returns an |X509_LOOKUP| associated with |store| with type |method|, or NULL on error. The result is owned by |store|, so callers are not expected to free it. This may be used with |X509_LOOKUP_add_dir| or |X509_LOOKUP_load_file|, depending on |method|, to configure |store|.

A single |X509_LOOKUP| may be configured with multiple paths, and an |X509_STORE| only contains one |X509_LOOKUP| of each type, so there is no need to call this function multiple times for a single type. Calling it multiple times will return the previous |X509_LOOKUP| of that type.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Pointer<X509_LOOKUP> Function(
    ffi.Pointer<X509_STORE>,
    ffi.Pointer<X509_LOOKUP_METHOD>,
  )
>(symbol: 'bssl_dart_X509_STORE_add_lookup')
external ffi.Pointer<X509_LOOKUP> X509_STORE_add_lookup(
  ffi.Pointer<X509_STORE> store,
  ffi.Pointer<X509_LOOKUP_METHOD> method,
);