X509_STORE_get1_objects function

  1. @RecordUse.new()
  2. @Native<Pointer<stack_st_X509_OBJECT> Function(Pointer<X509_STORE> store)>(ffi.Pointer<X509_STORE>)>(symbol: 'bssl_dart_X509_STORE_get1_objects')
Pointer<stack_st_X509_OBJECT> X509_STORE_get1_objects(
  1. Pointer<X509_STORE> store
)

X509_STORE_get1_objects returns a newly-allocated stack containing the contents of |store|, or NULL on error. The caller must release the result with |sk_X509_OBJECT_pop_free| and |X509_OBJECT_free| when done.

The result will include all certificates and CRLs added via |X509_STORE_add_cert| and |X509_STORE_add_crl|, as well as any cached objects added by |X509_LOOKUP_add_dir|. The last of these may change over time, as different objects are loaded from the filesystem. Callers should not depend on this caching behavior. The objects are returned in no particular order.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Pointer<stack_st_X509_OBJECT> Function(ffi.Pointer<X509_STORE>)
>(symbol: 'bssl_dart_X509_STORE_get1_objects')
external ffi.Pointer<stack_st_X509_OBJECT> X509_STORE_get1_objects(
  ffi.Pointer<X509_STORE> store,
);