X509_STORE_set_default_paths function
- @RecordUse.new()
- @Native<Int Function(Pointer<
X509_STORE> )>(ffi.Pointer<X509_STORE>)>(symbol: 'bssl_dart_X509_STORE_set_default_paths')
- Pointer<
X509_STORE> store
X509_STORE_set_default_paths configures |store| to read from some "default" filesystem paths. It returns one on success and zero on error. The filesystem paths are determined by a combination of hardcoded paths and the SSL_CERT_DIR and SSL_CERT_FILE environment variables.
Using this function is not recommended. In OpenSSL, these defaults are determined by OpenSSL's install prefix. There is no corresponding concept for BoringSSL. Future versions of BoringSSL may change or remove this functionality.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<X509_STORE>)>(
symbol: 'bssl_dart_X509_STORE_set_default_paths',
)
external int X509_STORE_set_default_paths(
ffi.Pointer<X509_STORE> store,
);