X509_VERIFY_PARAM_add1_host function
- Pointer<
X509_VERIFY_PARAM> param, - Pointer<
Char> name, - int name_len
X509_VERIFY_PARAM_add1_host adds |name| to the list of names checked by |param|. If any configured DNS name matches the certificate, verification succeeds. It returns one on success and zero on error.
By default, both subject alternative names and the subject's common name attribute are checked. The latter has long been deprecated, so callers should call |X509_VERIFY_PARAM_set_hostflags| with |X509_CHECK_FLAG_NEVER_CHECK_SUBJECT| to use the standard behavior. https://crbug.com/boringssl/464 tracks fixing the default.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<X509_VERIFY_PARAM>,
ffi.Pointer<ffi.Char>,
ffi.Size,
)
>(symbol: 'bssl_dart_X509_VERIFY_PARAM_add1_host')
external int X509_VERIFY_PARAM_add1_host(
ffi.Pointer<X509_VERIFY_PARAM> param,
ffi.Pointer<ffi.Char> name,
int name_len,
);