X509_cmp_time function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<ASN1_OCTET_STRING>, Pointer<Long>)>(ffi.Pointer<ASN1_TIME>, ffi.Pointer<time_t>)>(symbol: 'bssl_dart_X509_cmp_time')
int X509_cmp_time(
  1. Pointer<ASN1_OCTET_STRING> s,
  2. Pointer<Long> t
)

X509_cmp_time compares |s| against |*t|. On success, it returns a negative number if |s| <= |*t| and a positive number if |s| > |*t|. On error, it returns zero. If |t| is NULL, it uses the current time instead of |*t|.

WARNING: Unlike most comparison functions, this function returns zero on error, not equality.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<ASN1_TIME>, ffi.Pointer<time_t>)>(
  symbol: 'bssl_dart_X509_cmp_time',
)
external int X509_cmp_time(
  ffi.Pointer<ASN1_TIME> s,
  ffi.Pointer<time_t> t,
);