X509_get_extended_key_usage function
X509_get_extended_key_usage returns a bitmask of extended key usages (see Section 4.2.1.12 of RFC 5280) which |x509| is valid for. The result will be a combination of |XKU_*| constants. If checking an extended key usage not defined above, callers should extract the extended key usage extension separately, e.g. via |X509_get_ext_d2i|.
If |x509| has no extended key usage extension, all extended key usages are valid and this function returns |UINT32_MAX|. If there was an error processing |x509|'s extensions, or if |x509|'s extended key usage extension contained no recognized usages, this function returns zero.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Uint32 Function(ffi.Pointer<X509>)>(
symbol: 'bssl_dart_X509_get_extended_key_usage',
)
external int X509_get_extended_key_usage(
ffi.Pointer<X509> x509,
);