X509_load_cert_crl_file function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<X509_LOOKUP>, Pointer<Char>, Int)>(ffi.Pointer<X509_LOOKUP>, ffi.Pointer<ffi.Char>, ffi.Int)>(symbol: 'bssl_dart_X509_load_cert_crl_file')
int X509_load_cert_crl_file(
  1. Pointer<X509_LOOKUP> lookup,
  2. Pointer<Char> file,
  3. int type
)

X509_load_cert_crl_file loads CRLs and trusted certificates from |file| and adds them to |lookup|'s |X509_STORE|. It returns one on success and zero on error.

If |type| is |X509_FILETYPE_ASN1|, it loads a single DER-encoded certificate. This function cannot be used to load a DER-encoded CRL. If |type| is |X509_FILETYPE_PEM|, it loads a sequence of PEM-encoded certificates and CRLs. |type| may not be |X509_FILETYPE_DEFAULT|.

Implementation

@meta.RecordUse()
@ffi.Native<
  ffi.Int Function(ffi.Pointer<X509_LOOKUP>, ffi.Pointer<ffi.Char>, ffi.Int)
>(symbol: 'bssl_dart_X509_load_cert_crl_file')
external int X509_load_cert_crl_file(
  ffi.Pointer<X509_LOOKUP> lookup,
  ffi.Pointer<ffi.Char> file,
  int type,
);