X509_set1_signature_algo function

  1. @RecordUse.new()
  2. @Native<Int Function(Pointer<X509>, Pointer<X509_ALGOR>)>(ffi.Pointer<X509>, ffi.Pointer<X509_ALGOR>)>(symbol: 'bssl_dart_X509_set1_signature_algo')
int X509_set1_signature_algo(
  1. Pointer<X509> x509,
  2. Pointer<X509_ALGOR> algo
)

X509_set1_signature_algo sets |x509|'s signature algorithm to |algo| and returns one on success or zero on error. It updates both the signature field of the TBSCertificate structure, and the signatureAlgorithm field of the Certificate.

Implementation

@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<X509>, ffi.Pointer<X509_ALGOR>)>(
  symbol: 'bssl_dart_X509_set1_signature_algo',
)
external int X509_set1_signature_algo(
  ffi.Pointer<X509> x509,
  ffi.Pointer<X509_ALGOR> algo,
);