crypto_ivec_st class final
crypto_ivec_st (aka |CRYPTO_IVEC|) combines a pointer to input data with its length. It is usually passed as an array of length of at most |CRYPTO_IOVEC_MAX|.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
in$
↔ Pointer<
Uint8> -
getter/setter pair
- len ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited