ecdsa_sig_st class final

Low-level signing and verification.

Low-level functions handle signatures as |ECDSA_SIG| structures which allow the two values in an ECDSA signature to be handled separately.

Inheritance
Implemented types
Available extensions

Constructors

ecdsa_sig_st()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
r ↔ Pointer<BIGNUM>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s ↔ Pointer<BIGNUM>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$allocate(Allocator $allocator, {required Pointer<BIGNUM> r, required Pointer<BIGNUM> s}) → Pointer<ECDSA_SIG>