fips_counter_t class sealed
fips_counter_t denotes specific APIs/algorithms. A counter is maintained for each in FIPS mode so that tests can be written to assert that the expected, FIPS functions are being called by a certain piece of code.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fips_counter_evp_aes_128_ctr → const int
- fips_counter_evp_aes_128_gcm → const int
- fips_counter_evp_aes_256_ctr → const int
- fips_counter_evp_aes_256_gcm → const int
- fips_counter_max → const int