point_conversion_form_t class sealed

point_conversion_form_t enumerates forms, as defined in X9.62 (ECDSA), for the encoding of a elliptic curve point (x,y)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

POINT_CONVERSION_COMPRESSED → const int
POINT_CONVERSION_COMPRESSED indicates that the point is encoded as z||x, where the octet z specifies which solution of the quadratic equation y is.
POINT_CONVERSION_HYBRID → const int
POINT_CONVERSION_HYBRID indicates that the point is encoded as z||x||y, where z specifies which solution of the quadratic equation y is. This is not supported by the code and has never been observed in use.
POINT_CONVERSION_UNCOMPRESSED → const int
POINT_CONVERSION_UNCOMPRESSED indicates that the point is encoded as z||x||y, where z is the octet 0x04.