sk_X509_free_func typedef

Certificates.

An |X509| object represents an X.509 certificate, defined in RFC 5280.

Although an |X509| is a mutable object, mutating an |X509| can give incorrect results. Callers typically obtain |X509|s by parsing some input with |d2i_X509|, etc. Such objects carry information such as the serialized TBSCertificate and decoded extensions, which will become inconsistent when mutated.

Instead, mutation functions should only be used when issuing new certificates, as described in a later section.

Implementation

typedef sk_X509_free_func =
    ffi.Pointer<ffi.NativeFunction<sk_X509_free_funcFunction>>;