stack_st_X509_EXTENSION class final

Extension lists.

The following functions manipulate lists of extensions. Most of them have corresponding functions on the containing |X509|, |X509_CRL|, or |X509_REVOKED|.

Inheritance

Constructors

stack_st_X509_EXTENSION()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited