AES_ofb128_encrypt function
AES_ofb128_encrypt encrypts (or decrypts, it's the same in OFB mode) |len| bytes from |in| to |out|. The |num| parameter must be set to zero on the first call. This function may be called in-place with |in| equal to |out|, but otherwise the buffers may not partially overlap. A partial overlap may overwrite input data before it is read.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Void Function(
ffi.Pointer<ffi.Uint8>,
ffi.Pointer<ffi.Uint8>,
ffi.Size,
ffi.Pointer<AES_KEY>,
ffi.Pointer<ffi.Uint8>,
ffi.Pointer<ffi.Int>,
)
>(symbol: 'bssl_dart_AES_ofb128_encrypt')
external void AES_ofb128_encrypt(
ffi.Pointer<ffi.Uint8> in$,
ffi.Pointer<ffi.Uint8> out,
int len,
ffi.Pointer<AES_KEY> key,
ffi.Pointer<ffi.Uint8> ivec,
ffi.Pointer<ffi.Int> num,
);