BIO_get_mem_data function
BIO_get_mem_data sets |*contents| to point to the current contents of |bio| and returns the length of the data.
WARNING: don't use this, use |BIO_mem_contents|. A return value of zero from this function can mean either that it failed or that the memory buffer is empty.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Long Function(ffi.Pointer<BIO>, ffi.Pointer<ffi.Pointer<ffi.Char>>)
>(symbol: 'bssl_dart_BIO_get_mem_data')
external int BIO_get_mem_data(
ffi.Pointer<BIO> bio,
ffi.Pointer<ffi.Pointer<ffi.Char>> contents,
);