BIO_set_fd function
BIO_set_fd sets the file descriptor of |bio| to |fd|. If |close_flag| is non-zero then |fd| will be closed when |bio| is. It returns one on success or zero on error.
This function may also be used with socket BIOs (see |BIO_s_socket| and |BIO_new_socket|).
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<BIO>, ffi.Int, ffi.Int)>(
symbol: 'bssl_dart_BIO_set_fd',
)
external int BIO_set_fd(
ffi.Pointer<BIO> bio,
int fd,
int close_flag,
);