BIO_should_retry function
BIO_should_retry returns non-zero if the reason that caused a failed I/O operation is temporary and thus the operation should be retried. Otherwise, it was a permanent error and it returns zero.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<BIO>)>(
symbol: 'bssl_dart_BIO_should_retry',
)
external int BIO_should_retry(
ffi.Pointer<BIO> bio,
);