BN_bn2hex function
BN_bn2hex returns an allocated string that contains a NUL-terminated, hex representation of |bn|. If |bn| is negative, the first char in the resulting string will be '-'. Returns NULL on allocation failure.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<ffi.Char> Function(ffi.Pointer<BIGNUM>)>(
symbol: 'bssl_dart_BN_bn2hex',
)
external ffi.Pointer<ffi.Char> BN_bn2hex(
ffi.Pointer<BIGNUM> bn,
);