BN_get_word function
BN_get_word returns the absolute value of |bn| as a single word. If |bn| is too large to be represented as a single word, the maximum possible value will be returned.
Implementation
@meta.RecordUse()
@ffi.Native<BN_ULONG Function(ffi.Pointer<BIGNUM>)>(
symbol: 'bssl_dart_BN_get_word',
)
external int BN_get_word(
ffi.Pointer<BIGNUM> bn,
);