BN_num_bytes function
- @RecordUse.new()
- @Native<UnsignedInt Function(Pointer<
BIGNUM> )>(ffi.Pointer<BIGNUM>)>(symbol: 'bssl_dart_BN_num_bytes')
BN_num_bytes returns the minimum number of bytes needed to represent the absolute value of |bn|.
While |size_t| is the preferred type for byte counts, callers can assume that |BIGNUM|s are bounded such that this value, and its corresponding bit count, will always fit in |int|.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.UnsignedInt Function(ffi.Pointer<BIGNUM>)>(
symbol: 'bssl_dart_BN_num_bytes',
)
external int BN_num_bytes(
ffi.Pointer<BIGNUM> bn,
);