DH_set0_pqg function
DH_set0_pqg sets |dh|'s p, q, and g parameters to the specified values. If NULL, the field is left unchanged. On success, it takes ownership of each argument and returns one. Otherwise, it returns zero. |q| may be NULL, but |p| and |g| must either be specified or already configured on |dh|.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<DH>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BIGNUM>,
)
>(symbol: 'bssl_dart_DH_set0_pqg')
external int DH_set0_pqg(
ffi.Pointer<DH> dh,
ffi.Pointer<BIGNUM> p,
ffi.Pointer<BIGNUM> q,
ffi.Pointer<BIGNUM> g,
);