ECDSA_do_sign function
ECDSA_do_sign signs |digest_len| bytes from |digest| with |key| and returns the resulting signature structure, or NULL on error.
WARNING: |digest| must be the output of some hash function on the data to be signed. Passing unhashed inputs will not result in a secure signature scheme.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Pointer<ECDSA_SIG> Function(
ffi.Pointer<ffi.Uint8>,
ffi.Size,
ffi.Pointer<EC_KEY>,
)
>(symbol: 'bssl_dart_ECDSA_do_sign')
external ffi.Pointer<ECDSA_SIG> ECDSA_do_sign(
ffi.Pointer<ffi.Uint8> digest,
int digest_len,
ffi.Pointer<EC_KEY> key,
);