EC_GROUP_get_curve_GFp function
EC_GROUP_get_curve_GFp gets various parameters about a group. It sets |*out_p| to the order of the coordinate field and |*out_a| and |*out_b| to the parameters of the curve when expressed as y² = x³ + ax + b. Any of the output parameters can be NULL. It returns one on success and zero on error. |ctx| is ignored and may be NULL.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<EC_GROUP>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BN_CTX>,
)
>(symbol: 'bssl_dart_EC_GROUP_get_curve_GFp')
external int EC_GROUP_get_curve_GFp(
ffi.Pointer<EC_GROUP> group,
ffi.Pointer<BIGNUM> out_p,
ffi.Pointer<BIGNUM> out_a,
ffi.Pointer<BIGNUM> out_b,
ffi.Pointer<BN_CTX> ctx,
);