ERR_get_error function
ERR_get_error gets the packed error code for the least recent error and removes that error from the queue. If there are no errors in the queue then it returns zero.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Uint32 Function()>(symbol: 'bssl_dart_ERR_get_error')
external int ERR_get_error();