ERR_reason_error_string function
ERR_reason_error_string returns a string representation of the reason for |packed_error|, or a placeholder string if the reason is unrecognized.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<ffi.Char> Function(ffi.Uint32)>(
symbol: 'bssl_dart_ERR_reason_error_string',
)
external ffi.Pointer<ffi.Char> ERR_reason_error_string(
int packed_error,
);