EVP_DecodeBlock function
EVP_DecodeBlock encodes |src_len| bytes from |src| and writes the result to |dst|. It returns the number of bytes written or -1 on error.
WARNING: EVP_DecodeBlock's return value does not take padding into account. It also strips leading whitespace and trailing whitespace and minuses.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(ffi.Pointer<ffi.Uint8>, ffi.Pointer<ffi.Uint8>, ffi.Size)
>(symbol: 'bssl_dart_EVP_DecodeBlock')
external int EVP_DecodeBlock(
ffi.Pointer<ffi.Uint8> dst,
ffi.Pointer<ffi.Uint8> src,
int src_len,
);