EVP_PKEY_keygen function
EVP_PKEY_keygen performs a key generation operation using the values from |ctx|. If |*out_pkey| is non-NULL, it overwrites |*out_pkey| with the resulting key. Otherwise, it sets |*out_pkey| to a newly-allocated |EVP_PKEY| containing the result. It returns one on success or zero on error.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<EVP_PKEY_CTX>,
ffi.Pointer<ffi.Pointer<EVP_PKEY>>,
)
>(symbol: 'bssl_dart_EVP_PKEY_keygen')
external int EVP_PKEY_keygen(
ffi.Pointer<EVP_PKEY_CTX> ctx,
ffi.Pointer<ffi.Pointer<EVP_PKEY>> out_pkey,
);