EVP_PKEY_size function
EVP_PKEY_size returns the maximum size, in bytes, of a signature signed by |pkey|. For an RSA key, this returns the number of bytes needed to represent the modulus. For an EC key, this returns the maximum size of a DER-encoded ECDSA signature.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<EVP_PKEY>)>(
symbol: 'bssl_dart_EVP_PKEY_size',
)
external int EVP_PKEY_size(
ffi.Pointer<EVP_PKEY> pkey,
);