POLICYQUALINFO_st class final
A POLICYQUALINFO represents a PolicyQualifierInfo structure (RFC 5280). |d| contains the qualifier field of the PolicyQualifierInfo. Its type is determined by |pqualid|. If |pqualid| is |NID_id_qt_cps|, |d| must be |cpsuri|. If |pqualid| is |NID_id_qt_unotice|, |d| must be |usernotice|. Otherwise, |d| must be |other|.
WARNING: |pqualid| and |d| must be kept consistent. An inconsistency will result in a potentially exploitable memory error.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - d ↔ UnnamedUnion$6
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pqualid
↔ Pointer<
ASN1_OBJECT> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited