RSA_check_key function
RSA_check_key performs basic validity tests on |rsa|. It returns one if they pass and zero otherwise. Opaque keys and public keys always pass. If it returns zero then a more detailed error is available on the error queue.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<RSA>)>(
symbol: 'bssl_dart_RSA_check_key',
)
external int RSA_check_key(
ffi.Pointer<RSA> rsa,
);