RSA_generate_key_ex function
RSA_generate_key_ex generates a new RSA key where the modulus has size |bits| and the public exponent is |e|. If unsure, |RSA_F4| is a good value for |e|. If |cb| is not NULL then it is called during the key generation process. In addition to the calls documented for |BN_generate_prime_ex|, it is called with event=2 when the n'th prime is rejected as unsuitable and with event=3 when a suitable value for |p| is found.
It returns one on success or zero on error.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<RSA>,
ffi.Int,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BN_GENCB>,
)
>(symbol: 'bssl_dart_RSA_generate_key_ex')
external int RSA_generate_key_ex(
ffi.Pointer<RSA> rsa,
int bits,
ffi.Pointer<BIGNUM> e,
ffi.Pointer<BN_GENCB> cb,
);