RSA_set0_crt_params function
RSA_set0_crt_params sets |rsa|'s CRT parameters to |dmp1|, |dmq1|, and |iqmp|, if non-NULL, and takes ownership of them. On success, it takes ownership of its parameters and returns one. Otherwise, it returns zero.
Each argument must either be non-NULL or already configured on |rsa|.
It is an error to call this function after |rsa| has been used for a cryptographic operation. Construct a new |RSA| object instead.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<RSA>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BIGNUM>,
ffi.Pointer<BIGNUM>,
)
>(symbol: 'bssl_dart_RSA_set0_crt_params')
external int RSA_set0_crt_params(
ffi.Pointer<RSA> rsa,
ffi.Pointer<BIGNUM> dmp1,
ffi.Pointer<BIGNUM> dmq1,
ffi.Pointer<BIGNUM> iqmp,
);