RSA_size function
- @RecordUse.new()
- @Native<UnsignedInt Function(Pointer<
RSA> )>(ffi.Pointer<RSA>)>(symbol: 'bssl_dart_RSA_size')
RSA_size returns the number of bytes in the modulus, which is also the size of a signature or encrypted value using |rsa|.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.UnsignedInt Function(ffi.Pointer<RSA>)>(
symbol: 'bssl_dart_RSA_size',
)
external int RSA_size(
ffi.Pointer<RSA> rsa,
);