X509V3_EXT_d2i function
- @RecordUse.new()
- @Native<Pointer<
Void> Function(Pointer<X509_EXTENSION> ext)>(ffi.Pointer<X509_EXTENSION>)>(symbol: 'bssl_dart_X509V3_EXT_d2i')
- Pointer<
X509_EXTENSION> ext
X509V3_EXT_d2i decodes |ext| and returns a pointer to a newly-allocated structure, with type dependent on the type of the extension. It returns NULL if |ext| is an unsupported extension or if there was a syntax error in the extension. The caller should cast the return value to the expected type and free the structure when done.
WARNING: Casting the return value to the wrong type is a potentially exploitable memory error, so callers must not use this function before checking |ext| is of a known type. See the list at the top of this section for the correct types.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<ffi.Void> Function(ffi.Pointer<X509_EXTENSION>)>(
symbol: 'bssl_dart_X509V3_EXT_d2i',
)
external ffi.Pointer<ffi.Void> X509V3_EXT_d2i(
ffi.Pointer<X509_EXTENSION> ext,
);