X509_STORE_CTX_get_error function
- @RecordUse.new()
- @Native<Int Function(Pointer<
X509_STORE_CTX> )>(ffi.Pointer<X509_STORE_CTX>)>(symbol: 'bssl_dart_X509_STORE_CTX_get_error')
- Pointer<
X509_STORE_CTX> ctx
X509_STORE_CTX_get_error, after |X509_verify_cert| returns, returns |X509_V_OK| if verification succeeded or an |X509_V_ERR_*| describing why verification failed. This will be consistent with |X509_verify_cert|'s return value, unless the caller used the deprecated verification callback (see |X509_STORE_CTX_set_verify_cb|) in a way that breaks |ctx|'s invariants.
If called during the deprecated verification callback when |ok| is zero, it returns the current error under consideration.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<X509_STORE_CTX>)>(
symbol: 'bssl_dart_X509_STORE_CTX_get_error',
)
external int X509_STORE_CTX_get_error(
ffi.Pointer<X509_STORE_CTX> ctx,
);