X509_STORE_CTX_set0_trusted_stack function
- @RecordUse.new()
- @Native<Void Function(Pointer<
X509_STORE_CTX> , Pointer<stack_st_X509> )>(ffi.Pointer<X509_STORE_CTX>, ffi.Pointer<stack_st_X509>)>(symbol: 'bssl_dart_X509_STORE_CTX_set0_trusted_stack')
- Pointer<
X509_STORE_CTX> ctx, - Pointer<
stack_st_X509> sk
X509_STORE_CTX_set0_trusted_stack configures |ctx| to trust the certificates in |sk|. |sk| must remain valid for the duration of |ctx|. Calling this function causes |ctx| to ignore any certificates configured in the |X509_STORE|. Certificates in |sk| are still subject to the check described in |X509_VERIFY_PARAM_set_trust|.
WARNING: This function differs from most |set0| functions in that it does not take ownership of its input. The caller is required to ensure the lifetimes are consistent.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Void Function(ffi.Pointer<X509_STORE_CTX>, ffi.Pointer<stack_st_X509>)
>(symbol: 'bssl_dart_X509_STORE_CTX_set0_trusted_stack')
external void X509_STORE_CTX_set0_trusted_stack(
ffi.Pointer<X509_STORE_CTX> ctx,
ffi.Pointer<stack_st_X509> sk,
);