X509_STORE_load_locations function
X509_STORE_load_locations configures |store| to load data from filepaths |file| and |dir|. It returns one on success and zero on error. Either of |file| or |dir| may be NULL, but at least one must be non-NULL.
If |file| is non-NULL, it loads CRLs and trusted certificates in PEM format from the file at |file|, and them to |store|, as in |X509_load_cert_crl_file| with |X509_FILETYPE_PEM|.
If |dir| is non-NULL, it configures |store| to load CRLs and trusted certificates from the directory at |dir| in PEM format, as in |X509_LOOKUP_add_dir| with |X509_FILETYPE_PEM|.
Implementation
@meta.RecordUse()
@ffi.Native<
ffi.Int Function(
ffi.Pointer<X509_STORE>,
ffi.Pointer<ffi.Char>,
ffi.Pointer<ffi.Char>,
)
>(symbol: 'bssl_dart_X509_STORE_load_locations')
external int X509_STORE_load_locations(
ffi.Pointer<X509_STORE> store,
ffi.Pointer<ffi.Char> file,
ffi.Pointer<ffi.Char> dir,
);