X509_cmp_time_posix function
- @RecordUse.new()
- @Native<Int Function(Pointer<
ASN1_OCTET_STRING> , Int64)>(ffi.Pointer<ASN1_TIME>, ffi.Int64)>(symbol: 'bssl_dart_X509_cmp_time_posix')
- Pointer<
ASN1_OCTET_STRING> s, - int t
X509_cmp_time_posix compares |s| against |t|. On success, it returns a negative number if |s| <= |t| and a positive number if |s| > |t|. On error, it returns zero.
WARNING: Unlike most comparison functions, this function returns zero on error, not equality.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<ASN1_TIME>, ffi.Int64)>(
symbol: 'bssl_dart_X509_cmp_time_posix',
)
external int X509_cmp_time_posix(
ffi.Pointer<ASN1_TIME> s,
int t,
);