X509_get0_authority_issuer function
- @RecordUse.new()
- @Native<Pointer<
GENERAL_NAMES> Function(Pointer<X509> x509)>(ffi.Pointer<X509>)>(symbol: 'bssl_dart_X509_get0_authority_issuer')
X509_get0_authority_issuer returns the authorityCertIssuer of |x509|'s authority key identifier, if the extension and field are present. (See RFC 5280, section 4.2.1.1.) It returns NULL if the extension is not present, if it is present but lacks a authorityCertIssuer field, or if some extension in |x509| was invalid.
TODO(crbug.com/boringssl/381): Decoding an |X509| object will not check for invalid extensions. To detect the error case, call |X509_get_extension_flags| and check the |EXFLAG_INVALID| bit.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Pointer<GENERAL_NAMES> Function(ffi.Pointer<X509>)>(
symbol: 'bssl_dart_X509_get0_authority_issuer',
)
external ffi.Pointer<GENERAL_NAMES> X509_get0_authority_issuer(
ffi.Pointer<X509> x509,
);