d2i_ASN1_BOOLEAN function
- @RecordUse.new()
- @Native<ASN1_BOOLEAN Function(Pointer<
Int> , Pointer<Pointer< , Long)>(ffi.Pointer<ASN1_BOOLEAN>, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>, ffi.Long)>(symbol: 'bssl_dart_d2i_ASN1_BOOLEAN')UnsignedChar> >
d2i_ASN1_BOOLEAN parses a DER-encoded ASN.1 BOOLEAN from up to |len| bytes at |*inp|. On success, it advances |*inp| by the number of bytes read and returns the result. If |out| is non-NULL, it additionally writes the result to |*out|. On error, it returns |ASN1_BOOLEAN_NONE|.
This function does not reject trailing data in the input. This allows the caller to parse a sequence of concatenated structures. Callers parsing only one structure should check for trailing data by comparing the updated |*inp| with the end of the input.
WARNING: This function's is slightly different from other |d2i_*| functions because |ASN1_BOOLEAN| is not a pointer type.
Implementation
@meta.RecordUse()
@ffi.Native<
ASN1_BOOLEAN Function(
ffi.Pointer<ASN1_BOOLEAN>,
ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
ffi.Long,
)
>(symbol: 'bssl_dart_d2i_ASN1_BOOLEAN')
external int d2i_ASN1_BOOLEAN(
ffi.Pointer<ASN1_BOOLEAN> out,
ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> inp,
int len,
);