env_md_ctx_st class final
env_md_ctx_st is typoed ("evp" -> "env"), but the typo comes from OpenSSL and some consumers forward-declare these structures so we're leaving it alone.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
digest
↔ Pointer<
EVP_MD> -
digest is the underlying digest function, or NULL if not set.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pctx
↔ Pointer<
EVP_PKEY_CTX> -
pctx is an opaque (at this layer) pointer to additional context that
EVP_PKEY functions may store in this object.
getter/setter pair
-
pctx_ops
↔ Pointer<
evp_md_pctx_ops> -
pctx_ops, if not NULL, points to a vtable that contains functions to
manipulate |pctx|.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unnamed ↔ UnnamedUnion$2
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited