i2a_ASN1_OBJECT function
i2a_ASN1_OBJECT writes a human-readable representation of |a| to |bp|. It returns the number of bytes written on success, or a negative number on error. On error, this function may have written a partial output to |bp|.
Implementation
@meta.RecordUse()
@ffi.Native<ffi.Int Function(ffi.Pointer<BIO>, ffi.Pointer<ASN1_OBJECT>)>(
symbol: 'bssl_dart_i2a_ASN1_OBJECT',
)
external int i2a_ASN1_OBJECT(
ffi.Pointer<BIO> bp,
ffi.Pointer<ASN1_OBJECT> a,
);