private_key_st class final
X.509 information.
|X509_INFO| is the return type for |PEM_X509_INFO_read_bio|, defined in <openssl/pem.h>. It is used to store a certificate, CRL, or private key. This type is defined in this header for OpenSSL compatibility.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
dec_pkey
↔ Pointer<
EVP_PKEY> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited