rsa_pss_params_st class final
An rsa_pss_params_st, aka |RSA_PSS_PARAMS|, represents a parsed RSASSA-PSS-params structure, as defined in (RFC 4055).
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
hashAlgorithm
↔ Pointer<
X509_ALGOR> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maskGenAlgorithm
↔ Pointer<
X509_ALGOR> -
getter/setter pair
-
maskHash
↔ Pointer<
X509_ALGOR> -
OpenSSL caches the MGF hash on |RSA_PSS_PARAMS| in some cases. None of the
cases apply to BoringSSL, so this is always NULL, but Node expects the
field to be present.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
saltLength
↔ Pointer<
ASN1_OCTET_STRING> -
getter/setter pair
-
trailerField
↔ Pointer<
ASN1_OCTET_STRING> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
$allocate(
Allocator $allocator, {required Pointer< X509_ALGOR> hashAlgorithm, required Pointer<X509_ALGOR> maskGenAlgorithm, required Pointer<ASN1_OCTET_STRING> saltLength, required Pointer<ASN1_OCTET_STRING> trailerField, required Pointer<X509_ALGOR> maskHash}) → Pointer<RSA_PSS_PARAMS>