stack_st_ASN1_OBJECT class final
Object identifiers.
An |ASN1_OBJECT| represents a ASN.1 OBJECT IDENTIFIER. See also obj.h for additional functions relating to |ASN1_OBJECT|.
TODO(davidben): What's the relationship between asn1.h and obj.h? Most of obj.h deals with the large NID table, but then functions like |OBJ_get0_data| or |OBJ_dup| are general |ASN1_OBJECT| functions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited